Usage:  p3vlink <OPERATION> [VLINK-OPTIONS] 

One of the following operations can be used per command:
--show                		Shows all VLM (Virtual Link Module) data
--show-device         		Show single device data
--show-vlink-data     		Show vlink detailed properties, vlink selection is done by vlink-name or
                      		vlink-id,direction and ne-name it belongs to.
--show-vlinks         		Show all vlinks on specific sce
--show-subs           		Show all subscribers connected to specific device interface,
                      		or related to specific device. 
                      		When using the show specific device option, you can use the 
                      		vlink-id and/or direction options for filtering.
--show-vlink-details        Shows maximum number and available number of vlinks and channels for the SCE.                		
--resync              		Re-synchronizes selected SCEs with virtual link database
--resync-all          		Re-synchronizes all SCEs with virtual link database
--start-query      	  		Start query process on specific device.
--remove-device       		Remove Dynamic device from VLM.
--enable-logging      		Enable logging for specific device
--disable-logging     		Disable logging for specific device	
--import-cmts-details 		Import the CMTS credentials from a file.
--show-vlink-mappings 		Displays the vlink mapping tables
--show-subs-partial-vlink 	Displays subscriber with partial vlink and default vlink
--import-queue				Import selective subscriber(via csv file)/single subs in to primary queue.
--query-subs-partial-vlink 	To query all subscriber(s) from data base for the device name provided in 
							the CLU and add it in primary queue process for SNMP BG query.
--import-subs-into-db		Import subscribers with giaddr for specific device into database or file.       
--snmp-bg-query				To add the subscribers in primary queue of SNMP BG process.
--debug-snmp-bg				To debug the ipdr subscriber to find service flow,mac domain,direction,vlink
							and channel name which are current for the subscriber.

Vlink options:
--file-name           A complete path to the file which contains the device credentials.
                       Used with --import-cmts-details to specify the input file name.
Device options:
-d/--device=NAME      Perform the operation using this device NAME. 
                       Mandatory option with --show-device , --start-query operations, 
                       --import-subs-into-db,--snmp-bg-query and --show-subs-partial-vlink and  
                       Optional option with --show-subs and --show-vlink-mappings  operation.
-n/--ne-name=NAME     Perform the operation using this sce NAME. Mandatory option
                       with --show-vlinks and --resync operations.
--vlink-id=VLink Idx  Perform the operation on specific vlink index. Optional option
                       with --show-subs operation.
--vlink-name=NAME     Perform the operation on specific vlink name. Mandatory option
                       with --show-vlink-data operation.
--channel-name=NAME   Perform the operation on specific channel name. Used to list the 
                      subscribers on a specific channel. Optional option with --show-subs operation.                       
--direction=          Represents the Vlink Direction, possible values are  up or down.
[up/down/both]        Optional option with --show-subs , --show-subs-partial-vlink and 
                       --show-vlink-mappings -d operation. both is applicable only for 
                       --show-subs-partial-vlink operation.   
--prefix=NAME         Used with --show-vlinks, --show-subs commands for filtered 
                       vlinks (Optional).
--detail              Used with the --show-device operation to display 
                       additional information (Optional).
-o/--output=	      Where to extract the subscriber information file to.
                       relative to the SM root directory.Optional option with --import-subs-into-db
-m/--mode=             Perform the subscriber query operation for various mode
                       (subscribers having partial vlink mappings, full associated and all subscribers)
                        Mandatory option with --snmp-bg-query	
-s/--subs              Subscriber Name.	
--filter=              Displays the specified vlink mappings.Optional option with --show-vlink-mappings.			  
[ipdr/dhcp] 
								  
